@@ -2,8 +2,8 @@
 
 import ao
 
-id = ao.get_driver_id('oss')
-dev = ao.AudioDevice(id)
+dev = ao.AudioDevice('wav', bits=16)
 f = open('test.wav', 'r')
 data = f.read()
 dev.play(data, len(data))
+
